# metacopier-api

Explore the power of the MetaCopier API! Our RESTful API offers scalable and secure access to accounts, projects, and more. Get started quickly with authentication, explore endpoints, and access code samples in various languages.<br/><br/>All dates are in ISO 8601<br/><br/>This API is not designed for real-time communication purposes. For instance, continuously polling account information such as open positions every second is not recommended.<br/><br/>Our frontend uses this API, so you can look at the requests on our frontend for examples.

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 0.9.0
- Package version: 1.0.0
- Generator version: 7.8.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
  For more information, please visit [https://metacopier.io](https://metacopier.io)

## Requirements.

Python 3.7+

## Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from metacopier_api.api.account_api_api import AccountAPIApi
from metacopier_api.api_client import ApiClient
from metacopier_api.configuration import Configuration
from metacopier_api.exceptions import ApiException

# Defining the host is optional and defaults to https://api.metacopier.io
# See configuration.py for a list of all supported configuration parameters.
configuration = Configuration(
    host = "https://api.metacopier.io"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure API key authorization: ApiKeyAuth
configuration.api_key['ApiKeyAuth'] = os.environ["API_KEY"]

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['ApiKeyAuth'] = 'Bearer'


# Enter a context with an instance of the API client
with ApiClient(configuration) as api_client:
    # Create an instance of the API class
    accountClient = AccountAPIApi(api_client)

    try:
        # Send request to fetch accounts
        accounts = accountClient.get_accounts()

        # Print response
        print(accounts)
    except ApiException as e:
        print("Exception when calling AccountAPIApi->create_account: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.metacopier.io*

| Class           | Method                                                                                                             | HTTP request                                                                                                 | Description                                |
| --------------- | ------------------------------------------------------------------------------------------------------------------ | ------------------------------------------------------------------------------------------------------------ | ------------------------------------------ |
| _AccountAPIApi_ | [**create_account**](docs/AccountAPIApi.md#create_account)                                                         | **POST** /rest/api/v1/accounts                                                                               | Create an account                          |
| _AccountAPIApi_ | [**create_account_feature**](docs/AccountAPIApi.md#create_account_feature)                                         | **POST** /rest/api/v1/accounts/{accountId}/features                                                          | Create an account feature                  |
| _AccountAPIApi_ | [**create_copier**](docs/AccountAPIApi.md#create_copier)                                                           | **POST** /rest/api/v1/accounts/{accountId}/copiers                                                           | Create an account copier                   |
| _AccountAPIApi_ | [**create_copier_feature**](docs/AccountAPIApi.md#create_copier_feature)                                           | **POST** /rest/api/v1/accounts/{accountId}/copiers/{copierId}/features                                       | Create a copier feature                    |
| _AccountAPIApi_ | [**create_risk_limit**](docs/AccountAPIApi.md#create_risk_limit)                                                   | **POST** /rest/api/v1/accounts/{accountId}/riskLimits                                                        | Create an account risk limit               |
| _AccountAPIApi_ | [**delete_account**](docs/AccountAPIApi.md#delete_account)                                                         | **DELETE** /rest/api/v1/accounts/{accountId}                                                                 | Delete an account                          |
| _AccountAPIApi_ | [**delete_account_feature**](docs/AccountAPIApi.md#delete_account_feature)                                         | **DELETE** /rest/api/v1/accounts/{accountId}/features/{featureId}                                            | Delete an account feature                  |
| _AccountAPIApi_ | [**delete_copier**](docs/AccountAPIApi.md#delete_copier)                                                           | **DELETE** /rest/api/v1/accounts/{accountId}/copiers/{copierId}                                              | Delete an account copier                   |
| _AccountAPIApi_ | [**delete_copier_feature**](docs/AccountAPIApi.md#delete_copier_feature)                                           | **DELETE** /rest/api/v1/accounts/{accountId}/copiers/{copierId}/features/{featureId}                         | Delete a copier feature                    |
| _AccountAPIApi_ | [**delete_risk_limit**](docs/AccountAPIApi.md#delete_risk_limit)                                                   | **DELETE** /rest/api/v1/accounts/{accountId}/riskLimits/{riskLimitId}                                        | Delete an account risk limit               |
| _AccountAPIApi_ | [**get_account**](docs/AccountAPIApi.md#get_account)                                                               | **GET** /rest/api/v1/accounts/{accountId}                                                                    | Get an account                             |
| _AccountAPIApi_ | [**get_account_copier_current_symbol_mappings**](docs/AccountAPIApi.md#get_account_copier_current_symbol_mappings) | **GET** /rest/api/v1/accounts/{accountId}/copiers/{copierId}/symbolMappings/current                          | Get account copier current symbol mappings |
| _AccountAPIApi_ | [**get_account_feature**](docs/AccountAPIApi.md#get_account_feature)                                               | **GET** /rest/api/v1/accounts/{accountId}/features/{featureId}                                               | Get an account feature                     |
| _AccountAPIApi_ | [**get_account_features**](docs/AccountAPIApi.md#get_account_features)                                             | **GET** /rest/api/v1/accounts/{accountId}/features                                                           | Get all account features                   |
| _AccountAPIApi_ | [**get_account_logs**](docs/AccountAPIApi.md#get_account_logs)                                                     | **GET** /rest/api/v1/accounts/{accountId}/logs                                                               | Get account logs                           |
| _AccountAPIApi_ | [**get_accounts**](docs/AccountAPIApi.md#get_accounts)                                                             | **GET** /rest/api/v1/accounts                                                                                | Get all accounts                           |
| _AccountAPIApi_ | [**get_copier**](docs/AccountAPIApi.md#get_copier)                                                                 | **GET** /rest/api/v1/accounts/{accountId}/copiers/{copierId}                                                 | Get account copier                         |
| _AccountAPIApi_ | [**get_copier_feature**](docs/AccountAPIApi.md#get_copier_feature)                                                 | **GET** /rest/api/v1/accounts/{accountId}/copiers/{copierId}/features/{featureId}                            | Get a copier feature                       |
| _AccountAPIApi_ | [**get_copier_features**](docs/AccountAPIApi.md#get_copier_features)                                               | **GET** /rest/api/v1/accounts/{accountId}/copiers/{copierId}/features                                        | Get all copier features                    |
| _AccountAPIApi_ | [**get_copiers**](docs/AccountAPIApi.md#get_copiers)                                                               | **GET** /rest/api/v1/accounts/{accountId}/copiers                                                            | Get account copiers                        |
| _AccountAPIApi_ | [**get_risk_limit**](docs/AccountAPIApi.md#get_risk_limit)                                                         | **GET** /rest/api/v1/accounts/{accountId}/riskLimits/{riskLimitId}                                           | Get an account risk limit                  |
| _AccountAPIApi_ | [**get_risk_limits**](docs/AccountAPIApi.md#get_risk_limits)                                                       | **GET** /rest/api/v1/accounts/{accountId}/riskLimits                                                         | Get account risk limits                    |
| _AccountAPIApi_ | [**reset_risk_limit**](docs/AccountAPIApi.md#reset_risk_limit)                                                     | **PUT** /rest/api/v1/accounts/{accountId}/riskLimits/{riskLimitId}/reset                                     | Reset an account risk limit                |
| _AccountAPIApi_ | [**start_account**](docs/AccountAPIApi.md#start_account)                                                           | **POST** /rest/api/v1/accounts/{accountId}/actions/start                                                     | Start an account (connect)                 |
| _AccountAPIApi_ | [**stop_account**](docs/AccountAPIApi.md#stop_account)                                                             | **POST** /rest/api/v1/accounts/{accountId}/actions/stop                                                      | Stop an account (disconnect)               |
| _AccountAPIApi_ | [**update_account**](docs/AccountAPIApi.md#update_account)                                                         | **PUT** /rest/api/v1/accounts/{accountId}                                                                    | Update an account                          |
| _AccountAPIApi_ | [**update_account_feature**](docs/AccountAPIApi.md#update_account_feature)                                         | **PUT** /rest/api/v1/accounts/{accountId}/features/{featureId}                                               | Update an account feature                  |
| _AccountAPIApi_ | [**update_copier**](docs/AccountAPIApi.md#update_copier)                                                           | **PUT** /rest/api/v1/accounts/{accountId}/copiers/{copierId}                                                 | Update an account copier                   |
| _AccountAPIApi_ | [**update_copier_feature**](docs/AccountAPIApi.md#update_copier_feature)                                           | **PUT** /rest/api/v1/accounts/{accountId}/copiers/{copierId}/features/{featureId}                            | Update a copier feature                    |
| _AccountAPIApi_ | [**update_risk_limit**](docs/AccountAPIApi.md#update_risk_limit)                                                   | **PUT** /rest/api/v1/accounts/{accountId}/riskLimits/{riskLimitId}                                           | Update an account risk limit               |
| _ProjectAPIApi_ | [**acknowledge_all_logs**](docs/ProjectAPIApi.md#acknowledge_all_logs)                                             | **PUT** /rest/api/v1/projects/{projectId}/logs/acknowledgeAll                                                | Acknowledge all logs                       |
| _ProjectAPIApi_ | [**acknowledge_log**](docs/ProjectAPIApi.md#acknowledge_log)                                                       | **PUT** /rest/api/v1/projects/{projectId}/logs/{id}/acknowledge                                              | Acknowledge a log                          |
| _ProjectAPIApi_ | [**create_project_feature**](docs/ProjectAPIApi.md#create_project_feature)                                         | **POST** /rest/api/v1/projects/{projectId}/features                                                          | Create a project feature                   |
| _ProjectAPIApi_ | [**create_project_strategy**](docs/ProjectAPIApi.md#create_project_strategy)                                       | **POST** /rest/api/v1/projects/{projectId}/strategies                                                        | Create a strategy                          |
| _ProjectAPIApi_ | [**create_project_strategy_copier**](docs/ProjectAPIApi.md#create_project_strategy_copier)                         | **POST** /rest/api/v1/projects/{projectId}/strategies/{strategyId}/copiers                                   | Create a strategy copier                   |
| _ProjectAPIApi_ | [**create_project_strategy_copier_feature**](docs/ProjectAPIApi.md#create_project_strategy_copier_feature)         | **POST** /rest/api/v1/projects/{projectId}/strategies/{strategyId}/copiers/{copierId}/features               | Create a strategy copier feature           |
| _ProjectAPIApi_ | [**create_project_symbol_mapping**](docs/ProjectAPIApi.md#create_project_symbol_mapping)                           | **POST** /rest/api/v1/projects/{projectId}/symbolMappings                                                    | Create a symbol mapping                    |
| _ProjectAPIApi_ | [**delete_project_feature**](docs/ProjectAPIApi.md#delete_project_feature)                                         | **DELETE** /rest/api/v1/projects/{projectId}/features/{featureId}                                            | Delete a project feature                   |
| _ProjectAPIApi_ | [**delete_project_strategy**](docs/ProjectAPIApi.md#delete_project_strategy)                                       | **DELETE** /rest/api/v1/projects/{projectId}/strategies/{strategyId}                                         | Delete a strategy                          |
| _ProjectAPIApi_ | [**delete_project_strategy_copier**](docs/ProjectAPIApi.md#delete_project_strategy_copier)                         | **DELETE** /rest/api/v1/projects/{projectId}/strategies/{strategyId}/copiers/{copierId}                      | Delete a strategy copier                   |
| _ProjectAPIApi_ | [**delete_project_strategy_copier_feature**](docs/ProjectAPIApi.md#delete_project_strategy_copier_feature)         | **DELETE** /rest/api/v1/projects/{projectId}/strategies/{strategyId}/copiers/{copierId}/features/{featureId} | Delete a strategy copier feature           |
| _ProjectAPIApi_ | [**delete_project_symbol_mapping**](docs/ProjectAPIApi.md#delete_project_symbol_mapping)                           | **DELETE** /rest/api/v1/projects/{projectId}/symbolMappings/{symbolMappingId}                                | Delete a symbol mapping                    |
| _ProjectAPIApi_ | [**get_invoices**](docs/ProjectAPIApi.md#get_invoices)                                                             | **GET** /rest/api/v1/projects/{projectId}/invoices                                                           | Get all invoices                           |
| _ProjectAPIApi_ | [**get_project**](docs/ProjectAPIApi.md#get_project)                                                               | **GET** /rest/api/v1/projects/{projectId}                                                                    | Get a project                              |
| _ProjectAPIApi_ | [**get_project_feature**](docs/ProjectAPIApi.md#get_project_feature)                                               | **GET** /rest/api/v1/projects/{projectId}/features/{featureId}                                               | Get a project feature                      |
| _ProjectAPIApi_ | [**get_project_features**](docs/ProjectAPIApi.md#get_project_features)                                             | **GET** /rest/api/v1/projects/{projectId}/features                                                           | Get all project features                   |
| _ProjectAPIApi_ | [**get_project_logs**](docs/ProjectAPIApi.md#get_project_logs)                                                     | **GET** /rest/api/v1/projects/{projectId}/logs                                                               | Get project logs                           |
| _ProjectAPIApi_ | [**get_project_strategies**](docs/ProjectAPIApi.md#get_project_strategies)                                         | **GET** /rest/api/v1/projects/{projectId}/strategies                                                         | Get all strategies                         |
| _ProjectAPIApi_ | [**get_project_strategy**](docs/ProjectAPIApi.md#get_project_strategy)                                             | **GET** /rest/api/v1/projects/{projectId}/strategies/{strategyId}                                            | Get a strategy                             |
| _ProjectAPIApi_ | [**get_project_strategy_copier**](docs/ProjectAPIApi.md#get_project_strategy_copier)                               | **GET** /rest/api/v1/projects/{projectId}/strategies/{strategyId}/copiers/{copierId}                         | Get strategy copier                        |
| _ProjectAPIApi_ | [**get_project_strategy_copier_feature**](docs/ProjectAPIApi.md#get_project_strategy_copier_feature)               | **GET** /rest/api/v1/projects/{projectId}/strategies/{strategyId}/copiers/{copierId}/features/{featureId}    | Get a strategy copier feature              |
| _ProjectAPIApi_ | [**get_project_strategy_copier_features**](docs/ProjectAPIApi.md#get_project_strategy_copier_features)             | **GET** /rest/api/v1/projects/{projectId}/strategies/{strategyId}/copiers/{copierId}/features                | Get all strategy copier features           |
| _ProjectAPIApi_ | [**get_project_strategy_copiers**](docs/ProjectAPIApi.md#get_project_strategy_copiers)                             | **GET** /rest/api/v1/projects/{projectId}/strategies/{strategyId}/copiers                                    | Get strategy copiers                       |
| _ProjectAPIApi_ | [**get_project_symbol_mapping**](docs/ProjectAPIApi.md#get_project_symbol_mapping)                                 | **GET** /rest/api/v1/projects/{projectId}/symbolMappings/{symbolMappingId}                                   | Get a symbol mapping                       |
| _ProjectAPIApi_ | [**get_project_symbol_mappings**](docs/ProjectAPIApi.md#get_project_symbol_mappings)                               | **GET** /rest/api/v1/projects/{projectId}/symbolMappings                                                     | Get symbol mappings                        |
| _ProjectAPIApi_ | [**update_project**](docs/ProjectAPIApi.md#update_project)                                                         | **PUT** /rest/api/v1/projects/{projectId}                                                                    | Update a project                           |
| _ProjectAPIApi_ | [**update_project_feature**](docs/ProjectAPIApi.md#update_project_feature)                                         | **PUT** /rest/api/v1/projects/{projectId}/features/{featureId}                                               | Update a project feature                   |
| _ProjectAPIApi_ | [**update_project_strategy**](docs/ProjectAPIApi.md#update_project_strategy)                                       | **PUT** /rest/api/v1/projects/{projectId}/strategies/{strategyId}                                            | Update a strategy                          |
| _ProjectAPIApi_ | [**update_project_strategy_copier**](docs/ProjectAPIApi.md#update_project_strategy_copier)                         | **PUT** /rest/api/v1/projects/{projectId}/strategies/{strategyId}/copiers/{copierId}                         | Update a strategy copier                   |
| _ProjectAPIApi_ | [**update_project_strategy_copier_feature**](docs/ProjectAPIApi.md#update_project_strategy_copier_feature)         | **PUT** /rest/api/v1/projects/{projectId}/strategies/{strategyId}/copiers/{copierId}/features/{featureId}    | Update a strategy copier feature           |
| _ProjectAPIApi_ | [**update_project_symbol_mapping**](docs/ProjectAPIApi.md#update_project_symbol_mapping)                           | **PUT** /rest/api/v1/projects/{projectId}/symbolMappings/{symbolMappingId}                                   | Update a symbol mapping                    |
| _TradingAPIApi_ | [**close_all_positions**](docs/TradingAPIApi.md#close_all_positions)                                               | **POST** /rest/api/v1/accounts/{accountId}/actions/closeAllPositions                                         | Close all account positions                |
| _TradingAPIApi_ | [**close_position**](docs/TradingAPIApi.md#close_position)                                                         | **DELETE** /rest/api/v1/accounts/{accountId}/positions/{positionId}                                          | Close an account position                  |
| _TradingAPIApi_ | [**get_history_positions**](docs/TradingAPIApi.md#get_history_positions)                                           | **GET** /rest/api/v1/accounts/{accountId}/history/positions                                                  | Get account history positions              |
| _TradingAPIApi_ | [**get_information**](docs/TradingAPIApi.md#get_information)                                                       | **GET** /rest/api/v1/accounts/{accountId}/information                                                        | Get account information                    |
| _TradingAPIApi_ | [**get_positions**](docs/TradingAPIApi.md#get_positions)                                                           | **GET** /rest/api/v1/accounts/{accountId}/positions                                                          | Get account positions                      |
| _TradingAPIApi_ | [**modify_position**](docs/TradingAPIApi.md#modify_position)                                                       | **PUT** /rest/api/v1/accounts/{accountId}/positions/{positionId}                                             | Modify an account position                 |
| _TradingAPIApi_ | [**open_position**](docs/TradingAPIApi.md#open_position)                                                           | **POST** /rest/api/v1/accounts/{accountId}/positions                                                         | Open an account position                   |
| _TypeAPIApi_    | [**get_account_types**](docs/TypeAPIApi.md#get_account_types)                                                      | **GET** /rest/api/v1/types/accountTypes                                                                      | Get account type enum                      |
| _TypeAPIApi_    | [**get_currency_types**](docs/TypeAPIApi.md#get_currency_types)                                                    | **GET** /rest/api/v1/types/currencyTypes                                                                     | Get currency type enum                     |
| _TypeAPIApi_    | [**get_feature_types**](docs/TypeAPIApi.md#get_feature_types)                                                      | **GET** /rest/api/v1/types/featureTypes                                                                      | Get feature type enum                      |
| _TypeAPIApi_    | [**get_log_types**](docs/TypeAPIApi.md#get_log_types)                                                              | **GET** /rest/api/v1/types/logTypes                                                                          | Get log type enum                          |
| _TypeAPIApi_    | [**get_regions**](docs/TypeAPIApi.md#get_regions)                                                                  | **GET** /rest/api/v1/types/regions                                                                           | Get region enum                            |
| _TypeAPIApi_    | [**get_risk_types**](docs/TypeAPIApi.md#get_risk_types)                                                            | **GET** /rest/api/v1/types/riskTypes                                                                         | Get risk type enum                         |
| _TypeAPIApi_    | [**get_scale_types**](docs/TypeAPIApi.md#get_scale_types)                                                          | **GET** /rest/api/v1/types/scaleTypes                                                                        | Get scale type enum                        |

## Documentation For Models

- [AccountDTO](docs/AccountDTO.md)
- [AccountInformationDTO](docs/AccountInformationDTO.md)
- [AccountStatusDTO](docs/AccountStatusDTO.md)
- [AccountTypeDTO](docs/AccountTypeDTO.md)
- [CopierDTO](docs/CopierDTO.md)
- [CurrencyTypeDTO](docs/CurrencyTypeDTO.md)
- [FeatureCopierFilterDTO](docs/FeatureCopierFilterDTO.md)
- [FeatureDTO](docs/FeatureDTO.md)
- [FeatureKeepAliveTradeDTO](docs/FeatureKeepAliveTradeDTO.md)
- [FeaturePermittedSymbolsDTO](docs/FeaturePermittedSymbolsDTO.md)
- [FeatureSettingDTO](docs/FeatureSettingDTO.md)
- [FeatureTelegramNotificationDTO](docs/FeatureTelegramNotificationDTO.md)
- [FeatureTypeDTO](docs/FeatureTypeDTO.md)
- [InvoiceDTO](docs/InvoiceDTO.md)
- [LogDTO](docs/LogDTO.md)
- [LogTypeDTO](docs/LogTypeDTO.md)
- [PaymentMethodDTO](docs/PaymentMethodDTO.md)
- [PositionDTO](docs/PositionDTO.md)
- [PositionRequestDTO](docs/PositionRequestDTO.md)
- [ProjectDTO](docs/ProjectDTO.md)
- [RegionDTO](docs/RegionDTO.md)
- [RiskLimitDTO](docs/RiskLimitDTO.md)
- [RiskLimitStatusDTO](docs/RiskLimitStatusDTO.md)
- [RiskTypeDTO](docs/RiskTypeDTO.md)
- [ScaleTypeDTO](docs/ScaleTypeDTO.md)
- [StrategyDTO](docs/StrategyDTO.md)
- [SymbolMappingDTO](docs/SymbolMappingDTO.md)
- [TelegramNotificationDTO](docs/TelegramNotificationDTO.md)

<a id="documentation-for-authorization"></a>

## Documentation For Authorization

Authentication schemes defined for the API:
<a id="ApiKeyAuth"></a>

### ApiKeyAuth

- **Type**: API key
- **API key parameter name**: X-API-KEY
- **Location**: HTTP header

## Author
